# xemc3

A library for working with EMC3 simulations.

## Examples
Examples can be found under [docs/examples](docs/examples) and you can try them [online on binder](https://mybinder.org/v2/gh/dschwoerer/xemc3/next?filepath=docs%2Fexamples)

## Documentation
The documentation can be found on [read the docs](https://xemc3.rtfd.io)

## Installation
```bash
pip install xemc3
```
